========================================================
qirest: Quantitative Imaging Profile REST server
========================================================

`qiprofile <http://github.com/ohsu-qin/qiprofile/blob/master/doc/index.rst#quantitative-imaging-profile/>`_
REST API.
See the `documentation <http://qiprofile-rest.readthedocs.org/en/latest/>`_
for more information.
